@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-30'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -39,7 +39,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.03 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
 
 =head1 SYNOPSIS
 
@@ -83,6 +83,38 @@ L<Perl::Examples::Accessors::Scalar> 0.03
 
 =over
 
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
+=item * no generator (scalar-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
 =item * Moose (perl_code)
 
 Code template:
@@ -99,51 +131,11 @@ Code template:
 
 
 
-=item * raw-hash (perl_code)
+=item * Class::Accessor (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mouse->new
-
-
-
-=item * raw-array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessorArray->new
-
-
-
-=item * raw-scalar (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * Mo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mo->new
+ Perl::Examples::Accessors::ClassAccessor->new
 
 
 
@@ -155,14 +147,6 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessor->new
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -171,29 +155,45 @@ Code template:
 
 
 
+=item * Mouse (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mouse->new
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessorArray->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
- +--------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | participant              | rate (/s) | time (μs) | vs_slowest | result_size (b) | errors  | samples |
- +--------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | Moose                    | 4.8e+05   | 2.1       | 1          | 120             | 4.2e-09 | 20      |
- | Mo                       | 7.3e+05   | 1.4       | 1.5        | 120             | 2.1e-09 | 20      |
- | Moo                      | 9.27e+05  | 1.08      | 1.95       | 120             | 1.5e-10 | 20      |
- | Class::Accessor          | 1.05e+06  | 0.956     | 2.2        | 120             | 4e-10   | 25      |
- | Mouse                    | 1.33e+06  | 0.75      | 2.8        | 120             | 4.3e-10 | 20      |
- | raw-array                | 1.5e+06   | 0.65      | 3.2        | 64              | 1.6e-09 | 21      |
- | raw-hash                 | 1.9e+06   | 0.52      | 4          | 120             | 7.7e-10 | 24      |
- | Class::Accessor::Array   | 2e+06     | 0.5       | 4.2        | 64              | 1e-09   | 21      |
- | raw-scalar               | 2.1e+06   | 0.48      | 4.4        | 72              | 1.7e-09 | 24      |
- | Class::XSAccessor::Array | 3.13e+06  | 0.32      | 6.58       | 64              | 2.2e-10 | 22      |
- | Class::XSAccessor        | 3.2e+06   | 0.31      | 6.8        | 120             | 7.9e-10 | 23      |
- +--------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ | participant                 | rate (/s) | time (μs) | vs_slowest | result_size (b) | errors  | samples |
+ +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ | Moose                       | 4.2e+05   | 2.4       | 1          | 1.2e+02         | 2.5e-09 | 20      |
+ | Mo                          | 5.9e+05   | 1.7       | 1.4        | 1.2e+02         | 3.3e-09 | 21      |
+ | Moo                         | 8e+05     | 1.3       | 1.9        | 1.2e+02         | 1.7e-09 | 20      |
+ | Class::Accessor             | 8.6e+05   | 1.2       | 2          | 1.2e+02         | 1.7e-09 | 20      |
+ | Mouse                       | 1.254e+06 | 0.7971    | 2.964      | 120             | 2.3e-11 | 20      |
+ | no generator (array-based)  | 1.29e+06  | 0.777     | 3.04       | 64              | 4.2e-10 | 20      |
+ | no generator (hash-based)   | 1.64e+06  | 0.609     | 3.88       | 120             | 2.1e-10 | 24      |
+ | Class::Accessor::Array      | 1.7e+06   | 0.58      | 4.1        | 64              | 6.1e-10 | 21      |
+ | no generator (scalar-based) | 1.9e+06   | 0.54      | 4.4        | 72              | 7.5e-10 | 25      |
+ | Class::XSAccessor           | 2.57e+06  | 0.389     | 6.08       | 120             | 1.7e-10 | 37      |
+ | Class::XSAccessor::Array    | 2.71e+06  | 0.369     | 6.39       | 64              | 1.8e-10 | 34      |
+ +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
 
 =head1 DESCRIPTION
 
