@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-30'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.03 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
 
 =head1 SYNOPSIS
 
@@ -69,6 +69,24 @@ L<Mouse> v2.4.5
 
 =over
 
+=item * Mo (perl_code)
+
+L<Mo>
+
+
+
+=item *  (perl_code)
+
+
+
+=item *  (perl_code)
+
+
+
+=item *  (perl_code)
+
+
+
 =item * Moose (perl_code)
 
 L<Moose>
@@ -81,33 +99,9 @@ L<Class::XSAccessor>
 
 
 
-=item *  (perl_code)
+=item * Class::Accessor (perl_code)
 
-
-
-=item * Mouse (perl_code)
-
-L<Mouse>
-
-
-
-=item *  (perl_code)
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-L<Class::XSAccessor::Array>
-
-
-
-=item *  (perl_code)
-
-
-
-=item * Mo (perl_code)
-
-L<Mo>
+L<Class::Accessor>
 
 
 
@@ -117,38 +111,44 @@ L<Moo>
 
 
 
-=item * Class::Accessor (perl_code)
-
-L<Class::Accessor>
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 L<Class::Accessor::Array>
 
 
 
+=item * Mouse (perl_code)
+
+L<Mouse>
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+L<Class::XSAccessor::Array>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
 
  +--------------------------+-----------+------------------------+------------+---------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +--------------------------+-----------+------------------------+------------+---------+---------+
- | Moose                    | 1.9e+02   | 185                    | 1          | 0.0016  | 20      |
- | Mouse                    | 28        | 23                     | 6.7        | 0.00011 | 20      |
- | Moo                      | 21        | 16                     | 9          | 4.3e-05 | 22      |
- | Class::XSAccessor::Array | 13        | 8                      | 14         | 0.00011 | 20      |
- | Class::XSAccessor        | 13        | 8                      | 15         | 7.6e-05 | 20      |
- | Class::Accessor          | 12        | 7                      | 15         | 2.4e-05 | 20      |
- | Mo                       | 8         | 3                      | 2e+01      | 9.5e-05 | 20      |
- | Class::Accessor::Array   | 6.8       | 1.8                    | 28         | 1.3e-05 | 20      |
- | perl -e1 (baseline)      | 5         | 0                      | 4e+01      | 4.6e-05 | 20      |
+ | Moose                    | 3e+02     | 290                    | 1          | 0.0048  | 20      |
+ | Mouse                    | 7e+01     | 60                     | 5          | 0.0022  | 20      |
+ | Moo                      | 40        | 30                     | 7.5        | 0.00035 | 20      |
+ | Class::XSAccessor::Array | 4e+01     | 30                     | 9          | 0.00061 | 20      |
+ | Class::Accessor          | 3e+01     | 20                     | 1e+01      | 0.00064 | 20      |
+ | Class::XSAccessor        | 26        | 16                     | 11         | 0.00017 | 25      |
+ | Class::Accessor::Array   | 2e+01     | 10                     | 2e+01      | 0.00057 | 20      |
+ | Mo                       | 2e+01     | 10                     | 2e+01      | 0.00065 | 21      |
+ | perl -e1 (baseline)      | 1e+01     | 0                      | 2e+01      | 0.00045 | 20      |
  +--------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
