@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Read;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-30'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -12,14 +12,26 @@ our $scenario = {
     modules => {
     },
     participants => [
-        map {
+        (map {
             my $spec = $classes->{$_};
             +{
                 name => $spec->{generator} || $spec->{name},
                 module => $_,
                 code_template => "state \$o = do { my \$o = ${_}->new; \$o->attr1(42); \$o }; \$o->attr1",
             };
-        } grep { !$classes->{$_}{immutable} } keys %$classes,
+        } grep { !$classes->{$_}{immutable} } keys %$classes),
+
+        # also compare with raw hash & array access
+        {
+            name => 'raw hash access',
+            module => 'Perl::Examples::Accessors::Hash',
+            code_template => "state \$o = do { my \$o = Perl::Examples::Accessors::Hash->new; \$o->attr1(42); \$o }; \$o->{attr1}",
+        },
+        {
+            name => 'raw array access',
+            module => 'Perl::Examples::Accessors::Array',
+            code_template => "state \$o = do { my \$o = Perl::Examples::Accessors::Array->new; \$o->attr1(42); \$o }; \$o->[0]",
+        },
     ],
 };
 
@@ -38,7 +50,7 @@ Bencher::Scenario::Accessors::Read - Benchmark attribute read
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Accessors::Read (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.03 of Bencher::Scenario::Accessors::Read (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
 
 =head1 SYNOPSIS
 
@@ -80,6 +92,30 @@ L<Perl::Examples::Accessors::Mouse> 0.03
 
 =over
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
 =item * Moose (perl_code)
 
 Code template:
@@ -96,43 +132,11 @@ Code template:
 
 
 
-=item * raw-hash (perl_code)
+=item * Class::Accessor (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * raw-array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Mo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -144,14 +148,6 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -160,28 +156,62 @@ Code template:
 
 
 
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * raw hash access (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->{attr1}
+
+
+
+=item * raw array access (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o->attr1(42); $o }; $o->[0]
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Read >>):
 
- +--------------------------+-----------+-----------+------------+---------+---------+
- | participant              | rate (/s) | time (ns) | vs_slowest | errors  | samples |
- +--------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor          | 1.44e+06  | 696       | 1          | 6.9e-10 | 29      |
- | Mo                       | 3.27e+06  | 305       | 2.28       | 4.6e-11 | 20      |
- | raw-hash                 | 3.46e+06  | 289       | 2.41       | 1.4e-10 | 20      |
- | raw-array                | 3.64e+06  | 275       | 2.53       | 1.7e-10 | 26      |
- | Moose                    | 4e+06     | 2.5e+02   | 2.8        | 3.1e-10 | 28      |
- | Class::Accessor::Array   | 4.2e+06   | 2.4e+02   | 2.9        | 3.2e-10 | 20      |
- | Mouse                    | 9.52e+06  | 105       | 6.62       | 1.1e-11 | 20      |
- | Class::XSAccessor        | 1.1e+07   | 88        | 7.9        | 2.1e-10 | 20      |
- | Moo                      | 1.2e+07   | 83        | 8.3        | 3.8e-10 | 25      |
- | Class::XSAccessor::Array | 1.6e+07   | 61        | 11         | 2.4e-10 | 20      |
- +--------------------------+-----------+-----------+------------+---------+---------+
+ +----------------------------+-------------+-----------+------------+---------+---------+
+ | participant                | rate (/s)   | time (ns) | vs_slowest | errors  | samples |
+ +----------------------------+-------------+-----------+------------+---------+---------+
+ | Class::Accessor            | 1.22e+06    | 817       | 1          | 4.2e-10 | 20      |
+ | no generator (hash-based)  | 3.09e+06    | 323       | 2.53       | 2.1e-10 | 24      |
+ | Mo                         | 3.2e+06     | 3.2e+02   | 2.6        | 9.8e-10 | 24      |
+ | no generator (array-based) | 3.30369e+06 | 302.692   | 2.70029    | 0       | 20      |
+ | Moose                      | 3.6e+06     | 2.8e+02   | 2.9        | 3.1e-10 | 20      |
+ | Class::Accessor::Array     | 3.8e+06     | 2.6e+02   | 3.1        | 4.2e-10 | 20      |
+ | Mouse                      | 8.57e+06    | 117       | 7.01       | 2.2e-11 | 20      |
+ | Class::XSAccessor          | 1.1e+07     | 91        | 9          | 1.3e-10 | 30      |
+ | Moo                        | 1.2e+07     | 84        | 9.7        | 4.1e-10 | 21      |
+ | Class::XSAccessor::Array   | 1e+07       | 8e+01     | 1e+01      | 2.7e-09 | 27      |
+ | raw hash access            | 2e+07       | 49        | 17         | 2.2e-10 | 20      |
+ | raw array access           | 2.7e+07     | 37        | 22         | 2.1e-10 | 20      |
+ +----------------------------+-------------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
