@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Write;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-30'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -12,14 +12,26 @@ our $scenario = {
     modules => {
     },
     participants => [
-        map {
+        (map {
             my $spec = $classes->{$_};
             +{
                 name => $spec->{generator} || $spec->{name},
                 module => $_,
                 code_template => "state \$o = do { my \$o = ${_}->new; \$o }; \$o->attr1(42)",
             };
-        } grep { !$classes->{$_}{immutable} } keys %$classes,
+        } grep { !$classes->{$_}{immutable} } keys %$classes),
+
+        # also compare with raw hash & array access
+        {
+            name => 'raw hash access',
+            module => 'Perl::Examples::Accessors::Hash',
+            code_template => "state \$o = do { my \$o = Perl::Examples::Accessors::Hash->new; \$o }; \$o->{attr1} = 42",
+        },
+        {
+            name => 'raw array access',
+            module => 'Perl::Examples::Accessors::Array',
+            code_template => "state \$o = do { my \$o = Perl::Examples::Accessors::Array->new; \$o }; \$o->[0] = 42",
+        },
     ],
 };
 
@@ -38,7 +50,7 @@ Bencher::Scenario::Accessors::Write - Benchmark attribute read
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Accessors::Write (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.03 of Bencher::Scenario::Accessors::Write (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
 
 =head1 SYNOPSIS
 
@@ -80,6 +92,30 @@ L<Perl::Examples::Accessors::Mouse> 0.03
 
 =over
 
+=item * Mo (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
 =item * Moose (perl_code)
 
 Code template:
@@ -96,43 +132,11 @@ Code template:
 
 
 
-=item * raw-hash (perl_code)
+=item * Class::Accessor (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
-
-
-
-=item * raw-array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
-
-
-
-=item * Mo (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
 
 
 
@@ -144,14 +148,6 @@ Code template:
 
 
 
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -160,28 +156,62 @@ Code template:
 
 
 
+=item * Mouse (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Mouse->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+
+
+
+=item * raw hash access (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->{attr1} = 42
+
+
+
+=item * raw array access (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Array->new; $o }; $o->[0] = 42
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Write >>):
 
- +--------------------------+-----------+-----------+------------+---------+---------+
- | participant              | rate (/s) | time (ns) | vs_slowest | errors  | samples |
- +--------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor          | 1e+06     | 9.7e+02   | 1          | 1.3e-09 | 20      |
- | raw-hash                 | 2.58e+06  | 388       | 2.5        | 2.2e-10 | 22      |
- | raw-array                | 2.7e+06   | 3.7e+02   | 2.6        | 1e-09   | 20      |
- | Moose                    | 2.8e+06   | 3.6e+02   | 2.7        | 1.9e-09 | 20      |
- | Class::Accessor::Array   | 3.13e+06  | 319       | 3.04       | 2.4e-10 | 25      |
- | Mo                       | 3.4e+06   | 2.9e+02   | 3.3        | 4.8e-10 | 20      |
- | Mouse                    | 7.4e+06   | 1.3e+02   | 7.2        | 1.3e-09 | 20      |
- | Class::XSAccessor        | 9.1e+06   | 1.1e+02   | 8.8        | 1.4e-10 | 20      |
- | Class::XSAccessor::Array | 9.07e+06  | 110       | 8.79       | 1.1e-10 | 23      |
- | Moo                      | 9.6e+06   | 1e+02     | 9.3        | 1.6e-10 | 20      |
- +--------------------------+-----------+-----------+------------+---------+---------+
+ +----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                | rate (/s) | time (ns) | vs_slowest | errors  | samples |
+ +----------------------------+-----------+-----------+------------+---------+---------+
+ | Class::Accessor            | 8.79e+05  | 1.14e+03  | 1          | 3.7e-10 | 27      |
+ | no generator (hash-based)  | 2.126e+06 | 470.3     | 2.418      | 2.3e-11 | 26      |
+ | no generator (array-based) | 2.37e+06  | 422       | 2.7        | 2.3e-10 | 20      |
+ | Moose                      | 2.39e+06  | 418       | 2.72       | 6.8e-11 | 20      |
+ | Class::Accessor::Array     | 2.51e+06  | 398       | 2.86       | 2.1e-10 | 20      |
+ | Mo                         | 2.8e+06   | 3.6e+02   | 3.1        | 1.1e-09 | 34      |
+ | Mouse                      | 6.36e+06  | 157       | 7.24       | 2.3e-11 | 22      |
+ | Class::XSAccessor          | 6.9e+06   | 145       | 7.85       | 2.3e-11 | 20      |
+ | Moo                        | 6.9e+06   | 1.4e+02   | 7.9        | 4.1e-10 | 21      |
+ | Class::XSAccessor::Array   | 7.9e+06   | 1.3e+02   | 9          | 4.1e-10 | 21      |
+ | raw hash access            | 1.4e+07   | 74        | 15         | 2.2e-10 | 20      |
+ | raw array access           | 1.9e+07   | 53        | 21         | 2.1e-10 | 20      |
+ +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
